==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/tao/PortableServer/IdUniquenessStrategyUnique.h <==
// -*- C++ -*-

//=============================================================================
/**
 *  @file IdUniquenessStrategyUnique.h
 *
 *  IdUniquenessStrategyUnique.h,v 1.3 2005/02/21 18:13:50 jwillemsen Exp
 *
 *  @author  Johnny Willemsen  <jwillemsen@remedy.nl>
 */
//=============================================================================

#ifndef TAO_ID_UNIQUENESSSTRATEGYUNIQUE_H
#define TAO_ID_UNIQUENESSSTRATEGYUNIQUE_H
#include /**/ "ace/pre.h"

#include "portableserver_export.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "IdUniquenessStrategy.h"
#include "ace/Service_Config.h"

namespace TAO
{
  namespace Portable_Server
  {
    class TAO_PortableServer_Export IdUniquenessStrategyUnique
      : public IdUniquenessStrategy
    {
    public:
      IdUniquenessStrategyUnique (void);

      virtual void strategy_init (TAO_Root_POA *poa
                                  ACE_ENV_ARG_DECL);

      virtual void strategy_cleanup (ACE_ENV_SINGLE_ARG_DECL);

      virtual bool is_servant_activation_allowed (
        PortableServer::Servant servant,
        int &wait_occurred_restart_call);

      virtual bool allow_multiple_activations (void) const;

      virtual ::PortableServer::IdUniquenessPolicyValue type() const;

    private:
      TAO_Root_POA* poa_;
    };

    ACE_STATIC_SVC_DECLARE_EXPORT (TAO_PortableServer, IdUniquenessStrategyUnique)
    ACE_FACTORY_DECLARE (TAO_PortableServer, IdUniquenessStrategyUnique)
  }
}

#include /**/ "ace/post.h"
#endif /* TAO_ID_UNIQUENESSSTRATEGYUNIQUE_H */

==> ace_5.6.3.orig.tar.gz: ACE_wrappers/TAO/tao/PortableServer/IdUniquenessStrategyUnique.h <==
// -*- C++ -*-

//=============================================================================
/**
 *  @file IdUniquenessStrategyUnique.h
 *
 *  $Id: IdUniquenessStrategyUnique.h 76551 2007-01-24 13:42:44Z johnnyw $
 *
 *  @author  Johnny Willemsen  <jwillemsen@remedy.nl>
 */
//=============================================================================

#ifndef TAO_ID_UNIQUENESSSTRATEGYUNIQUE_H
#define TAO_ID_UNIQUENESSSTRATEGYUNIQUE_H
#include /**/ "ace/pre.h"

#include "tao/PortableServer/portableserver_export.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "tao/PortableServer/IdUniquenessStrategy.h"
#include "ace/Service_Config.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

namespace TAO
{
  namespace Portable_Server
  {
    class TAO_PortableServer_Export IdUniquenessStrategyUnique
      : public IdUniquenessStrategy
    {
    public:
      IdUniquenessStrategyUnique (void);

      virtual void strategy_init (TAO_Root_POA *poa
                                 );

      virtual void strategy_cleanup (void);

      virtual bool is_servant_activation_allowed (
        PortableServer::Servant servant,
        bool &wait_occurred_restart_call);

      virtual bool allow_multiple_activations (void) const;

      virtual ::PortableServer::IdUniquenessPolicyValue type() const;

    private:
      TAO_Root_POA* poa_;
    };

  }
}

TAO_END_VERSIONED_NAMESPACE_DECL

ACE_STATIC_SVC_DECLARE_EXPORT (TAO_PortableServer, IdUniquenessStrategyUnique)
ACE_FACTORY_DECLARE (TAO_PortableServer, IdUniquenessStrategyUnique)


#include /**/ "ace/post.h"
#endif /* TAO_ID_UNIQUENESSSTRATEGYUNIQUE_H */
